import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { SyncDescriptor } from 'vscode/vscode/vs/platform/instantiation/common/descriptors';
import { ILanguagePackService } from 'vscode/vscode/vs/platform/languagePacks/common/languagePacks';
import { ILocaleService } from 'vscode/vscode/vs/workbench/services/localization/common/locale';
import './override/vs/platform/dialogs/common/dialogs.js';
import { IHostService } from 'vscode/vscode/vs/workbench/services/host/browser/host';
import { IProductService } from 'vscode/vscode/vs/platform/product/common/productService';
import { localizeWithPath, localize } from 'vscode/vscode/vs/nls';
import { Language, language } from 'vscode/vscode/vs/base/common/platform';
import { URI } from 'vscode/vscode/vs/base/common/uri';
import { setAvailableLocales, getBuiltInExtensionTranslationsUris } from 'vscode/l10n';
import './vscode/src/vs/workbench/contrib/localization/browser/localization.contribution.js';
import { IDialogService } from 'vscode/vscode/vs/platform/dialogs/common/dialogs';

let LocaleService = class LocaleService {
    constructor(options, dialogService, hostService, productService) {
        this.options = options;
        this.dialogService = dialogService;
        this.hostService = hostService;
        this.productService = productService;
    }
    async setLocale(languagePackItem) {
        const locale = languagePackItem.id;
        if (locale === Language.value() || (locale == null && Language.value() === navigator.language.toLowerCase())) {
            return;
        }
        if (locale == null) {
            await this.options.clearLocale();
        }
        else {
            await this.options.setLocale(locale);
        }
        const restartDialog = await this.dialogService.confirm({
            type: 'info',
            message: ( localizeWithPath(
                'vs/workbench/services/localization/browser/localeService',
                'relaunchDisplayLanguageMessage',
                'To change the display language, {0} needs to reload',
                this.productService.nameLong
            )),
            detail: ( localizeWithPath(
                'vs/workbench/services/localization/browser/localeService',
                'relaunchDisplayLanguageDetail',
                'Press the reload button to refresh the page and set the display language to {0}.',
                languagePackItem.label
            )),
            primaryButton: ( localize(
                { key: 'reload', comment: ['&& denotes a mnemonic character'] },
                '&&Reload'
            ))
        });
        if (restartDialog.confirmed) {
            await this.hostService.restart();
        }
    }
    async clearLocalePreference() {
        await this.options.clearLocale();
        const restartDialog = await this.dialogService.confirm({
            type: 'info',
            message: ( localizeWithPath(
                'vs/workbench/services/localization/browser/localeService',
                'clearDisplayLanguageMessage',
                'To change the display language, {0} needs to reload',
                this.productService.nameLong
            )),
            detail: ( localizeWithPath(
                'vs/workbench/services/localization/browser/localeService',
                'clearDisplayLanguageDetail',
                "Press the reload button to refresh the page and use your browser's language."
            )),
            primaryButton: ( localize(
                { key: 'reload', comment: ['&& denotes a mnemonic character'] },
                '&&Reload'
            ))
        });
        if (restartDialog.confirmed) {
            await this.hostService.restart();
        }
    }
};
LocaleService = __decorate([
    ( __param(1, IDialogService)),
    ( __param(2, IHostService)),
    ( __param(3, IProductService))
], LocaleService);
class LanguagePackService {
    constructor(options) {
        this.options = options;
        setAvailableLocales(new Set(( options.availableLanguages.map(lang => lang.locale))));
    }
    async getAvailableLanguages() {
        return ( this.options.availableLanguages.map(({ locale, languageName }) => {
            const label = languageName ?? locale;
            let description;
            if (label !== locale) {
                description = `(${locale})`;
            }
            if (locale.toLowerCase() === language.toLowerCase()) {
                description ?? (description = '');
                description += ( localizeWithPath(
                    'vs/platform/languagePacks/common/languagePacks',
                    'currentDisplayLanguage',
                    ' (Current)'
                ));
            }
            return {
                id: locale,
                label,
                description
            };
        }));
    }
    async getInstalledLanguages() {
        return [];
    }
    async getBuiltInExtensionTranslationsUri(id, language) {
        const uri = getBuiltInExtensionTranslationsUris(language)?.[id];
        return uri != null ? ( URI.parse(uri)) : undefined;
    }
}
function getServiceOverride(options) {
    return {
        [( ILocaleService.toString())]: new SyncDescriptor(LocaleService, [options], true),
        [( ILanguagePackService.toString())]: new SyncDescriptor(LanguagePackService, [options], true)
    };
}

export { getServiceOverride as default };
